@@ -55,7 +55,9 @@ class Converter:
             'days': ['days', 'day', 'dys', 'dy', 'd'], 
             'weeks': ['weeks', 'week', 'wks', 'wk', 'w'], 
             'months': ['months', 'month', 'mons', 'mon', 'mn'], 
-            'years': ['years', 'year', 'yrs', 'yr', 'y']
+            'years': ['years', 'year', 'yrs', 'yr', 'y'],
+            'decades': ['decade', 'decades', 'dcd', 'dec'],
+            'centuries': ['century', 'centuries', 'c', 'cen']
         }
         self.raw_output = {
             'seconds': 0,
@@ -64,7 +66,9 @@ class Converter:
             'days': 0, 
             'weeks': 0, 
             'months': 0, 
-            'years': 0
+            'years': 0,
+            'decades': 0,
+            'centuries': 0
         }
 
     def convert(self):
@@ -93,6 +97,8 @@ class Converter:
             self.raw_output['months'] %= 12
         self.raw_output['days'] += round(30.5 * self.raw_output['months']) # datetime.timedelta does not support months
         self.raw_output['days'] += 365 * self.raw_output['years'] # datetime.timedelta does not support years
+        self.raw_output['days'] += 3650 * self.raw_output['decades'] # datetime.timedelta doesnt support decades so we just convert it to days
+        self.raw_output['days'] += 36500 * self.raw_output['centuries'] # datetime.timedelta doesnt support centurys
         self.output = datetime.timedelta(seconds=self.raw_output['seconds'], minutes=self.raw_output['minutes'], hours=self.raw_output['hours'], days=self.raw_output['days'], weeks=self.raw_output['weeks'])
         return self.output
 
@@ -114,6 +120,10 @@ def convert(input_string: str):
     return output
 
 
+__title__ = "time_str"
 __author__='BobDotCom'
-__version__='0.0.3post1'
+__version__='0.1.0.post2'
+
+__license__ = "MIT License"
+__copyright__ = "Copyright 2021 {}".format(__author__)
 
